@@ -4,6 +4,7 @@
     }
 
     .order-window {
+        page-break-after: always;
         border-bottom: 1px solid #000;
         width: 100%;
         display: block;
@@ -23,13 +24,23 @@
     }
 
     .ordered-items {
-        display: block !important;
+        box-sizing: border-box;
+        display: inline-block !important;
         padding: 15px 0;
+        width: 49% !important;
     }
 
     .ordered-items div {
         display: block;
     }
+
+    @media print {
+        .ordered-items {
+            display: inline-block !important;
+            padding: 15px 0;
+            width: 49% !important;
+        }
+    }
 </style>
 
 <?php
@@ -40,28 +51,37 @@ require_once($_SERVER['DOCUMENT_ROOT'] . '/wp-config.php');
 
 $date = $_GET['date'];
 $location = $_GET['location'];
+$status = $_GET['status'];
 
-$orders = B2\OrderController::getAllOrdersForPrint($location, $date);
+$orders = B2\OrderController::getAllOrdersForPrint($location, $date, $status);
 ?>
-<h2>Orders for: <?= date('d-m-Y', $date); ?></h2>
 
 <?php foreach ($orders as $order) { ?>
     <div class="order-window">
+        <h2>Collection Date: <?= date('d-m-Y', $date); ?></h2>
+        <p><strong>Customer Notes:</strong> <?= $order['notes']; ?></p>
         <div class="header">
             <div><strong>Order Id:</strong> <?= $order['order']['id'] ?></div>
-            <div><strong>Order Date:</strong> <?= date_format($order['order']['order_date'], 'd-m-Y') ?></div>
             <div><strong>Customer:</strong> <?= $order['order']['client_name']; ?></div>
             <div><strong>Contact Number:</strong> <?= $order['order']['contact_number']; ?></div>
             <div><strong>Shop Order Number:</strong> <?= $order['order']['shop_order_number']; ?></div>
-            <div><strong>Final Price:</strong> <?= $order['order']['final_price']; ?></div>
+            <div><strong>Estimated Price:</strong> £<?= $order['order']['estimated_price']; ?></div>
+            <div><strong>Final Price:</strong> £<?= $order['order']['final_price']; ?></div>
+            <?php if (isset($order['coupons'])) { ?>
+                <div><strong>Coupon:</strong> <?= $order['coupons']['description']; ?></div>
+                <div><?= $order['coupons']['amount']; ?></div>
+            <?php } ?>
         </div>
+
         <?php foreach ($order['orderItems'] as $orderItem) { ?>
             <div class="ordered-items">
                 <div><strong>Product Title:</strong> <?= $orderItem['product_title']; ?></div>
                 <div><strong>Product Weight:</strong> <?= $orderItem['weight']; ?></div>
-                <div><strong>Number of People:</strong> <?= $orderItem['people']; ?></div>
+                <div><strong>Unit Label:</strong> <?= $orderItem['unit_label']; ?></div>
+                <div><strong>Units:</strong> <?= $orderItem['unit']; ?></div>
                 <div><strong>Size: <?= $orderItem['size']; ?></strong></div>
                 <div><strong>Qty:</strong> <?= $orderItem['qty']; ?></div>
+                <div><strong>SKU:</strong> <?= $orderItem['sku']; ?></div>
             </div>
         <?php } ?>
     </div>
@@ -69,7 +89,9 @@ $orders = B2\OrderController::getAllOrdersForPrint($location, $date);
 
 <script>
     window.print();
-    location.replace('/click-collect-dashboard?location=<?= $location; ?>' );
+    window.onafterprint = function() {
+        location.replace('/click-collect-dashboard?location=<?= $location; ?>');
+    };
 </script>
 
 <?php exit; ?>
