@@ -277,7 +277,7 @@ class OrderController
         $orderItems['pickup_date'] = $shipping['Pickup Date'];
         $orderItems['price'] = $order->get_total();
         $orderItems['coupons'] = $coupons;
-
+        $orderItems['notes'] = $order->get_customer_note() ?: 'No note';
 
         $orderItems['orders'] = [];
         foreach ($order->get_items() as $itemKey => $item) {
@@ -285,7 +285,6 @@ class OrderController
 
             $orderItems['orders'][] = $newOrderItem->newOrderItemData();
         };
-
         return $orderItems;
     }
 
@@ -302,9 +301,9 @@ class OrderController
             $couponArray['title'] = $couponObject->get_code();
             $couponArray['description'] = $couponObject->get_description();
             if ($couponObject->get_discount_type() == 'percent') {
-                $couponArray['amount'] = $couponObject->get_amount().'%';
+                $couponArray['amount'] = $couponObject->get_amount() . '%';
             } else {
-                $couponArray['amount'] = '£'.$couponObject->get_amount();
+                $couponArray['amount'] = '£' . $couponObject->get_amount();
             }
 
         }
@@ -396,7 +395,7 @@ class OrderController
 
     }
 
-    public static function emailCustomerOrder($shopNumber, $order)
+    public function emailCustomerOrder($shopNumber, $order)
     {
         $shipping = self::getShippingDetails($order);
         $order = new Order($order);
@@ -413,58 +412,28 @@ class OrderController
 
         $to = $order->getEmail();
         $subject = 'Your Simon Howie Order is ready to collect at our ' . $shipping['Pickup Location'] . ' branch';
-        $message = '
-            <div style="background-color:#f7f7f7;padding:10px 100px;text-align:center;">
-            <img src="https://s3-eu-west-1.amazonaws.com/blue2digital/pex/simonhowie/2019/05/02152443/SimonHowie-logo-on-white.png" style="text-align:center;display:block;width:300px;padding:15px;height:auto;margin:15px auto;" alt="Simon Howie Logo">        
-            <div style="background-color:#ea7600;width:100%;color:#fff;font-size:28px;text-align:center;padding:10px 0;">Your Simon Howie Order</div>
-            <div style="background-color:#fff; padding:10px; text-align:left;">
-            Dear ' . $order->getName() . '<br>
-            This is to confirm your order will be ready to collect as requested on ' . date('l jS \of F Y', $date) . ' at ' . $shipping['Pickup Location'] . '<br>
-            Your shop order number is <strong style="color:#ea7600;">' . $shopNumber[0] . '</strong> please quote this when collecting your order.<br>
+        $template = 'ready';
 
-            The final price for the order is: <strong style="color:#ea7600;">£' . $finalPrice . '</strong>';
+        ob_start();
+        include $this->pluginDirectoryPath . "/templates/emails/ready-collect.php";
+        $message = ob_get_clean();
 
-        $message .= '<table style="border-collapse: collapse;padding:25px 0;">';
-        $message .= '<thead style="font-weight:bold;">';
-        $message .= '<tr style="border-bottom:1px solid #000; color: #ea7600;">';
-        $message .= '<td style="padding:10px;font-weight:bold;border:1px solid #ddd;">Product Title</td><td style="padding:10px;border:1px solid #ddd;">Weight (g)</td><td style="padding:10px;border:1px solid #ddd;">Pack Size</td><td style="padding:10px;border:1px solid #ddd;">Qty</td>';
-        $message .= '</tr>';
-        $message .= '</thead>';
-        $message .= '<tbody>';
-        foreach ($orderItems as $orderItem) {
-            $message .= '<tr>';
-            $message .= '<td style="padding:10px;border:1px solid #ddd;">' . $orderItem['product_title'] . '</td><td style="padding:10px;border:1px solid #ddd;">' . $orderItem['weight'] . '</td><td style="padding:10px;border:1px solid #ddd;">' . $orderItem['size'] . '</td><td style="padding:10px;border:1px solid #ddd;">' . $orderItem['qty'] . '</td>';
-            $message .= '</tr>';
-        };
-        $message .= '</tbody>';
-        $message .= '</table>';
-        $message .= '<br>';
-        $message .= '<br>';
-        $message .= 'For collection times please see our <a href="https://www.thescottishbutcher.com/local-butchers-perth-auchterarder/locations-opening-times/">website</a><br>';
-        $message .= 'A problem with your order or its collection? Please contact us at <a href="mailto:collect@simonhowiefoods.co.uk">collect@simonhowiefoods.co.uk</a><br>';
-        $message .= 'We look forward to welcoming you back to one of our stores.<br>';
-        $message .= 'Many thanks, The Simon Howie Team.<br>';
-        $message .= '</div>';
-        $message .= '</div>';
         $headers = ['Content-Type: text/html; charset=UTF-8'];
 
         wp_mail($to, $subject, $message, $headers);
     }
 
-    public static function emailCustomerThankYou($order)
+    public function emailCustomerThankYou($order)
     {
 
         $order = new Order($order);
 
         $to = $order->getEmail();
         $subject = 'Thank you for collecting your Simon Howie Order';
-        $message = '
-        <img src="https://s3-eu-west-1.amazonaws.com/blue2digital/pex/simonhowie/2019/05/02152443/SimonHowie-logo-on-white.png" style="display:block;width:300px;height:auto;margin:15px 0;" alt="Simon Howie Logo">
-        Dear ' . $order->getName() . '<br>Thank you for collecting your recent order.<br>';
-        $message .= 'We hope that you like our new Click & Collect service, if you have any feedback about our products please leave a review <a href="https://www.thescottishbutcher.com/review-our-products/">here</a>';
-        $message .= 'If you have had a problem with your order or its collection, please contact us at <a href="mailto:collect@simonhowiefoods.co.uk">collect@simonhowiefoods.co.uk</a><br>';
-        $message .= 'We look forward to welcoming you back to one of our stores.<br>';
-        $message .= 'Many thanks, The Simon Howie Team.<br>';
+        $template = 'thank-you';
+        ob_start();
+        include $this->pluginDirectoryPath . "/templates/emails/thank-you.php";
+        $message = ob_get_clean();
 
         $headers = ['Content-Type: text/html; charset=UTF-8'];
 
@@ -594,16 +563,24 @@ class OrderController
     {
         $orderData = [];
 
-        $order = new Order($order);
-        $orderId = $order->getOrderID();
+
+        $orderObject = new Order($order);
+        $orderId = $orderObject->getOrderID();
+
+        $coupons = self::getCoupons($orderId);
+
         if (!isset($orderData[$orderId])) {
             $orderData[$orderId] = [
-                'order' => $order->newOrderData(),
+                'order' => $orderObject->newOrderData(),
+                'coupons' => $coupons,
+                'notes' => $order->get_customer_note() ?: 'No note',
                 'orderItems' => [],
             ];
         }
         $orderItems = [];
-        foreach ($order->getOrderItems() as $itemKey => $item) {
+
+        foreach ($orderObject->getOrderItems() as $itemKey => $item) {
+
             $newOrderItem = new OrderItem($item, $itemKey, $orderId);
             $orderItems[] = $newOrderItem->newOrderItemData();
         };
@@ -641,19 +618,24 @@ class OrderController
                 $order = new Order($singleOrder);
                 $orderId = $order->getOrderID();
 
+                $wcOrder = wc_get_order($orderId);
+
                 if ($status === 'to-be-made') {
                     $statuses = ['5', '6', '7', '8'];
                 } else {
                     $statuses = ['6', '7', '8'];
                 }
 
-
                 if (!in_array($order->getOrderStatus(), $statuses)) {
 
                     if (!isset($orderData[$orderId])) {
+                        $coupons = self::getCoupons($orderId);
+
                         $orderData[$orderId] = [
                             'order' => $order->newOrderData(),
+                            'coupons' => $coupons,
                             'orderItems' => [],
+                            'notes' => $wcOrder->get_customer_note() ?: 'No note',
                         ];
                     }
 
